==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Arc/ArcCPA/ts/ArcCPA_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>ArcCPA</name>
    <message>
        <location filename="../ArcCPA.js" line="+66"/>
        <source>Center</source>
        <translation>Centro</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Point on arc or radius</source>
        <translation>Punto su arco o raggio</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Point on arc</source>
        <translation>Punto su arco</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Start angle</source>
        <translation>Angolo di partenza</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>End angle</source>
        <translation>Angolo finale</translation>
    </message>
    <message>
        <location filename="../ArcCPAInit.js" line="+2"/>
        <source>&amp;Center, Point, Angles</source>
        <translation>&amp;Centro, Punto, Angoli</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw arc from center, point on arc and angles</source>
        <translation>Disegna un arco dal centro, un punto l&apos;arco e gli angoli</translation>
    </message>
    <message>
        <location filename="../ArcCPA.ui" line="+17"/>
        <source>Direction:</source>
        <translation>Direzione:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Counter Clockwise (positive)</source>
        <translation>Senso antiorario (positivo)</translation>
    </message>
    <message>
        <location line="+13"/>
        <location line="+17"/>
        <source>Direction</source>
        <translation>Direzione</translation>
    </message>
    <message>
        <location line="-10"/>
        <source>Clockwise (Negative)</source>
        <translation>Senso orario (negativo)</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Arc/ArcCPA/ts/ArcCPA_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>ArcCPA</name>
    <message>
        <location filename="../ArcCPA.js" line="+66"/>
        <source>Center</source>
        <translation>Centro</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Point on arc or radius</source>
        <translation>Punto su arco o raggio</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Point on arc</source>
        <translation>Punto su arco</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Start angle</source>
        <translation>Angolo di partenza</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>End angle</source>
        <translation>Angolo finale</translation>
    </message>
    <message>
        <location filename="../ArcCPAInit.js" line="+2"/>
        <source>&amp;Center, Point, Angles</source>
        <translation>&amp;Centro, punto, angoli</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw arc from center, point on arc and angles</source>
        <translation>Disegna un arco dal centro, un punto l&apos;arco e gli angoli</translation>
    </message>
    <message>
        <location filename="../ArcCPA.ui" line="+17"/>
        <source>Direction:</source>
        <translation>Direzione:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Counter Clockwise (positive)</source>
        <translation>Senso antiorario (positivo)</translation>
    </message>
    <message>
        <location line="+13"/>
        <location line="+17"/>
        <source>Direction</source>
        <translation>Direzione</translation>
    </message>
    <message>
        <location line="-10"/>
        <source>Clockwise (Negative)</source>
        <translation>Senso orario (negativo)</translation>
    </message>
</context>
</TS>
